Learn R Programming

PACVr (version 1.0.11)

PACVr-package: PACVr: Plastome Assembly Coverage Visualization

Description

Visualizes the coverage depth of a complete plastid genome as well as the equality of its inverted repeat regions in relation to the circular, quadripartite genome structure and the location of individual genes. For more information, please see Gruenstaeudl and Jenke (2020) tools:::Rd_expr_doi("10.1186/s12859-020-3475-0").

Arguments

Author

Maintainer: Michael Gruenstaeudl m_gruenstaeudl@fhsu.edu (ORCID)

Other contributors:

  • Gregory Smith [contributor]

  • Nils Jenke [contributor]

See Also